@@ -47,10 +47,10 @@
 #include <gtk/gtksignal.h>
 #include <gdk/gdk.h>
 #include <glib/gi18n.h>
+#include <gio/gdesktopappinfo.h>
 #include <libgnome/gnome-init.h>
 #include <libgnomeui/gnome-ui-init.h>
 #include <libgnomeui/gnome-client.h>
-#include <libgnomevfs/gnome-vfs-init.h>
 #include <libnautilus-private/nautilus-debug-log.h>
 #include <libnautilus-private/nautilus-directory-metafile.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
@@ -85,7 +85,7 @@ quit_if_in_main_loop (gpointer callback_data)
 
 	level = gtk_main_level ();
 
-	/* We can be called even outside the main loop by gnome_vfs_shutdown,
+	/* We can be called even outside the main loop,
 	 * so check that we are in a loop before calling quit.
 	 */
 	if (level != 0) {
@@ -231,13 +231,6 @@ debug_log_io_cb (GIOChannel *io, GIOCondition condition, gpointer data)
 	return FALSE;
 }
 
-/* sigaction structures for the old handlers of these signals */
-static struct sigaction old_segv_sa;
-static struct sigaction old_abrt_sa;
-static struct sigaction old_trap_sa;
-static struct sigaction old_fpe_sa;
-static struct sigaction old_bus_sa;
-
 static void
 sigusr1_handler (int sig)
 {
@@ -245,6 +238,17 @@ sigusr1_handler (int sig)
 		;
 }
 
+/* This is totally broken as we're using non-signal safe
+ * calls in sigfatal_handler. Disable by default. */
+#ifdef USE_SEGV_HANDLER
+
+/* sigaction structures for the old handlers of these signals */
+static struct sigaction old_segv_sa;
+static struct sigaction old_abrt_sa;
+static struct sigaction old_trap_sa;
+static struct sigaction old_fpe_sa;
+static struct sigaction old_bus_sa;
+
 static void
 sigfatal_handler (int sig)
 {
@@ -287,6 +291,7 @@ sigfatal_handler (int sig)
 	if (func != NULL && func != SIG_IGN && func != SIG_DFL)
 		(* func) (sig);
 }
+#endif
 
 static void
 setup_debug_log_signals (void)
@@ -305,6 +310,9 @@ setup_debug_log_signals (void)
 	sa.sa_flags = 0;
 	sigaction (SIGUSR1, &sa, NULL);
 
+	/* This is totally broken as we're using non-signal safe
+	 * calls in sigfatal_handler. Disable by default. */
+#ifdef USE_SEGV_HANDLER
 	sa.sa_handler = sigfatal_handler;
 	sigemptyset (&sa.sa_mask);
 	sa.sa_flags = 0;
@@ -314,6 +322,7 @@ setup_debug_log_signals (void)
 	sigaction(SIGTRAP, &sa, &old_trap_sa);
 	sigaction(SIGFPE,  &sa, &old_fpe_sa);
 	sigaction(SIGBUS,  &sa, &old_bus_sa);
+#endif
 }
 
 static GLogFunc default_log_handler;
@@ -399,8 +408,13 @@ main (int argc, char *argv[])
 		{ NULL }
 	};
 
+	g_thread_init (NULL);
+
 	setlocale (LC_ALL, "");
 
+	/* This will be done by gtk+ later, but for now, force it to GNOME */
+	g_desktop_app_info_set_desktop_env ("GNOME");
+
 	if (g_getenv ("NAUTILUS_DEBUG") != NULL) {
 		eel_make_warnings_and_criticals_stop_in_debugger ();
 	}
@@ -415,7 +429,7 @@ main (int argc, char *argv[])
 	if (startup_id != NULL && *startup_id != '\0') {
 		/* Clear the DESKTOP_STARTUP_ID, but make sure to copy it first */
 		startup_id_copy = g_strdup (startup_id);
-		putenv ("DESKTOP_STARTUP_ID=");
+		g_unsetenv ("DESKTOP_STARTUP_ID");
 	}
 
 	/* we'll do it ourselves due to complicated factory setup */
@@ -525,8 +539,6 @@ main (int argc, char *argv[])
 #ifndef NAUTILUS_OMIT_SELF_CHECK
 		/* Run the checks (each twice) for nautilus and libnautilus-private. */
 
-		nautilus_directory_use_self_contained_metafile_factory ();
-
 		nautilus_run_self_checks ();
 		nautilus_run_lib_self_checks ();
 		eel_exit_if_self_checks_failed ();
@@ -556,17 +568,8 @@ main (int argc, char *argv[])
 		gtk_main ();
 	}
 
-	/* This has to be done before gnome_vfs_shutdown, because
- 	 * it might call nautilus_file_get_uri() which might call
- 	 * gnome_vfs_uri_append_string()
- 	 */
  	eel_debug_shut_down ();
 
-	gnome_vfs_shutdown ();
-
-	/* This has to be done after gnome_vfs_shutdown, because shutdown
-	 * can call pending completion callbacks which reference application.
-	 */
 	if (application != NULL) {
 		bonobo_object_unref (application);
 	}
